- Update to 11.0.696.65

- Fix build when ffmpeg-devel is installed [1] [2]
- Bring back proxy configuration detection [1]
- Minor enhancements [1]

Submitted by:	George Liaskos [geo.liaskos gmail.com] [1]
Reported by:	Mickael Maillot [mickael.maillot gmail.com] [2]
Obtained from:	freebsd-chromium development repository
Committed at:	FreeBSD Developer Summit 2011
This commit is contained in:
Rene Ladan 2011-05-11 19:28:56 +00:00
parent 551b721cb3
commit 72efc09096
Notes: svn2git 2021-03-31 03:12:20 +00:00
svn path=/head/; revision=273975
8 changed files with 99 additions and 65 deletions

View file

@ -7,8 +7,7 @@
PORTNAME= chromium
DISTVERSIONPREFIX= courgette-redacted-
DISTVERSION= 11.0.696.57
PORTREVISION= 1
DISTVERSION= 11.0.696.65
CATEGORIES= www
MASTER_SITES= http://download.goodking.org/downloads/ \
ftp://rene-ladan.nl/pub/distfiles/ \

View file

@ -1,2 +1,2 @@
SHA256 (chromium-courgette-redacted-11.0.696.57.tar.xz) = c269ecfd398d9a3bff6ea9af514e6090a50844ed9ce8e35a3045d4bc46621769
SIZE (chromium-courgette-redacted-11.0.696.57.tar.xz) = 115117312
SHA256 (chromium-courgette-redacted-11.0.696.65.tar.xz) = 8396a722339d51f3635527d912603908b52ff94813d23d96f9960767af6c45d7
SIZE (chromium-courgette-redacted-11.0.696.65.tar.xz) = 115136680

View file

@ -1,6 +1,6 @@
--- content/common/file_path_watcher/file_path_watcher_stub.cc.orig 2011-04-15 11:01:10.000000000 +0300
+++ content/common/file_path_watcher/file_path_watcher_stub.cc 2011-04-19 22:34:32.353038862 +0300
@@ -5,15 +5,21 @@
--- content/common/file_path_watcher/file_path_watcher_stub.cc.orig 2011-04-26 11:01:09.000000000 +0300
+++ content/common/file_path_watcher/file_path_watcher_stub.cc 2011-05-04 01:10:53.819147264 +0300
@@ -5,15 +5,23 @@
// This file exists for Unix systems which don't have the inotify headers, and
// thus cannot build file_watcher_inotify.cc
@ -9,8 +9,6 @@
class FilePathWatcherImpl : public FilePathWatcher::PlatformDelegate {
public:
+
+ virtual void Cancel() {}
+
virtual bool Watch(const FilePath& path,
- FileWatcher::Delegate* delegate,
@ -19,9 +17,13 @@
return false;
}
+
+ virtual void Cancel() OVERRIDE {
+ set_cancelled();
+ }
+
+ protected:
+
+ virtual void CancelOnMessageLoopThread() {}
+ virtual void CancelOnMessageLoopThread() OVERRIDE { }
};
FilePathWatcher::FilePathWatcher() {

View file

@ -1,6 +1,6 @@
--- net/net.gyp.orig 2011-03-20 22:02:04.177736414 +0200
+++ net/net.gyp 2011-03-20 22:02:04.391765571 +0200
@@ -137,8 +137,8 @@
--- net/net.gyp.orig 2011-04-26 11:01:16.000000000 +0300
+++ net/net.gyp 2011-05-03 21:16:49.479149025 +0300
@@ -138,8 +138,8 @@
'base/network_change_notifier_linux.h',
'base/network_change_notifier_mac.cc',
'base/network_change_notifier_mac.h',
@ -11,7 +11,7 @@
'base/network_change_notifier_win.cc',
'base/network_change_notifier_win.h',
'base/network_config_watcher_mac.cc',
@@ -242,7 +242,7 @@
@@ -245,7 +245,7 @@
'dependencies': [
'../build/linux/system.gyp:gconf',
'../build/linux/system.gyp:gdk',
@ -20,18 +20,7 @@
],
'conditions': [
['use_openssl==1', {
@@ -548,8 +548,8 @@
'proxy/proxy_config_service.h',
'proxy/proxy_config_service_fixed.cc',
'proxy/proxy_config_service_fixed.h',
- 'proxy/proxy_config_service_linux.cc',
- 'proxy/proxy_config_service_linux.h',
+ #'proxy/proxy_config_service_linux.cc',
+ #'proxy/proxy_config_service_linux.h',
'proxy/proxy_config_service_mac.cc',
'proxy/proxy_config_service_mac.h',
'proxy/proxy_config_service_win.cc',
@@ -1029,7 +1029,7 @@
@@ -1023,7 +1023,7 @@
],
}
],
@ -40,7 +29,7 @@
'conditions': [
['linux_use_tcmalloc==1', {
'dependencies': [
@@ -1194,7 +1194,7 @@
@@ -1196,7 +1196,7 @@
}],
],
}],

View file

@ -1,5 +1,5 @@
--- net/proxy/proxy_config_service_linux.cc.orig 2011-04-04 10:01:16.000000000 +0200
+++ net/proxy/proxy_config_service_linux.cc 2011-04-11 00:23:55.000000000 +0200
--- net/proxy/proxy_service.cc.orig 2011-03-20 22:02:04.206737865 +0200
+++ net/proxy/proxy_service.cc 2011-03-20 22:02:04.398743833 +0200
--- net/proxy/proxy_service.cc.orig 2011-04-26 11:01:15.000000000 +0300
+++ net/proxy/proxy_service.cc 2011-05-03 20:34:48.665149760 +0300
@@ -25,7 +25,7 @@
#elif defined(OS_MACOSX)
#include "net/proxy/proxy_config_service_mac.h"
#include "net/proxy/proxy_resolver_mac.h"
-#elif defined(OS_LINUX) && !defined(OS_CHROMEOS)
+#elif (defined(OS_LINUX) || defined(OS_FREEBSD)) && !defined(OS_CHROMEOS)
#include "net/proxy/proxy_config_service_linux.h"
#endif
#include "net/proxy/proxy_resolver.h"
@@ -124,6 +124,16 @@
}
};
@ -17,3 +26,12 @@
// ProxyResolver that simulates a PAC script which returns
// |pac_string| for every single URL.
class ProxyResolverFromPacString : public ProxyResolver {
@@ -795,7 +805,7 @@
NOTREACHED() << "ProxyConfigService for ChromeOS should be created in "
<< "chrome_url_request_context.cc::CreateProxyConfigService.";
return NULL;
-#elif defined(OS_LINUX)
+#elif defined(OS_LINUX) || defined(OS_FREEBSD)
ProxyConfigServiceLinux* linux_config_service
= new ProxyConfigServiceLinux();

View file

@ -1,5 +1,5 @@
--- third_party/ffmpeg/ffmpeg.gyp.orig 2011-04-26 11:02:53.000000000 +0300
+++ third_party/ffmpeg/ffmpeg.gyp 2011-04-29 01:18:16.629475671 +0300
--- third_party/ffmpeg/ffmpeg.gyp.orig 2011-05-08 00:21:12.884604466 +0300
+++ third_party/ffmpeg/ffmpeg.gyp 2011-05-08 00:23:54.819604306 +0300
@@ -50,7 +50,7 @@
}, {
'ffmpeg_config%': '<(target_arch)',
@ -39,16 +39,14 @@
'obj_format': 'elf',
'conditions': [
[ 'target_arch=="ia32"', {
@@ -720,6 +730,12 @@
},
}],
+ ['OS=="freebsd" and use_system_vpx==1', {
+ 'include_dirs': [
+ '/usr/local/include',
+ ],
+ }],
+
['use_system_vpx==0', {
@@ -754,6 +764,10 @@
'include_dirs': [
# TODO(fischman): when both mac & linux are building from
'config',
'patched-ffmpeg-mt',
+ # gliaskos: The following include is needed for libvpx,
+ # should remain _after_ patched-ffmpeg-mt or else
+ # ffmpeg_stubs.cc picks up system headers.
+ '/usr/local/include',
],
'direct_dependent_settings': {
'include_dirs': [

View file

@ -1,5 +1,5 @@
--- tools/gyp/pylib/gyp/generator/make.py.orig 2011-03-01 10:47:14.000000000 +0100
+++ tools/gyp/pylib/gyp/generator/make.py 2011-03-01 21:25:10.000000000 +0100
--- tools/gyp/pylib/gyp/generator/make.py.orig 2011-04-26 11:14:32.000000000 +0300
+++ tools/gyp/pylib/gyp/generator/make.py 2011-05-04 21:12:47.761273429 +0300
@@ -114,7 +114,7 @@
# export LINK="$(CXX)"
#
@ -30,3 +30,12 @@
ARFLAGS.host := %(ARFLAGS.host)s
# Flags to make gcc output dependency info. Note that you need to be
@@ -249,7 +249,7 @@
# so we can check their command lines.
# $? -- new prerequisites
# $| -- order-only dependencies
-prereq_changed = $(filter-out $|,$?)
+prereq_changed = $(filter-out FORCE_DO_CMD $|,$?)
# do_cmd: run a command via the above cmd_foo names, if necessary.
# Should always run for a given target to handle command-line changes.
--- net/proxy/proxy_config_service_linux.cc.orig 2011-04-26 11:01:15.000000000 +0300
+++ net/proxy/proxy_config_service_linux.cc 2011-05-04 23:52:01.546273478 +0300
@@ -12,7 +12,13 @@
#include <limits.h>
#include <stdio.h>
@ -23,7 +23,7 @@
auto_no_pac_(false), reversed_bypass_list_(false),
env_var_getter_(env_var_getter), file_loop_(NULL) {
// This has to be called on the UI thread (http://crbug.com/69057).
@@ -492,33 +498,37 @@
@@ -492,35 +498,43 @@
}
virtual ~GConfSettingGetterImplKDE() {
@ -61,7 +61,10 @@
}
- int flags = fcntl(inotify_fd_, F_GETFL);
- if (fcntl(inotify_fd_, F_SETFL, flags | O_NONBLOCK) < 0) {
+#if !defined(OS_FREEBSD)
+ int flags = fcntl(notify_fd_, F_GETFL);
+
+ // This call to fcntl returns ENOTTY on FreeBSD.
+ if (fcntl(notify_fd_, F_SETFL, flags | O_NONBLOCK) < 0) {
PLOG(ERROR) << "fcntl failed";
- close(inotify_fd_);
@ -70,8 +73,11 @@
+ notify_fd_ = -1;
return false;
}
+#endif
file_loop_ = file_loop;
@@ -529,28 +539,41 @@
// The initial read is done on the current thread, not |file_loop_|,
// since we will need to have it for SetupAndFetchInitialConfig().
@@ -529,28 +543,42 @@
}
void Shutdown() {
@ -92,14 +98,15 @@
+ DCHECK(notify_fd_ >= 0);
DCHECK(file_loop_);
+#if defined(OS_FREEBSD)
+ // catch the deletion event of kioslaverc
+ int kioslavercfd = open(kde_config_dir_.Append("kioslaverc").value().c_str(), O_RDONLY);
+ if (kioslavercfd == -1)
+ // Catch the deletion event of kioslaverc.
+ int fd = open(kde_config_dir_.Append("kioslaverc").value().c_str(),
+ O_RDONLY);
+ if (fd == -1)
+ return false;
+
+ struct kevent ke;
+ EV_SET(&ke, kioslavercfd, EVFILT_VNODE, EV_ADD | EV_ONESHOT, NOTE_DELETE | NOTE_RENAME, 0, NULL);
+
+ EV_SET(&ke, fd, EVFILT_VNODE, (EV_ADD | EV_CLEAR),
+ (NOTE_DELETE | NOTE_RENAME), 0, NULL);
+ if (kevent(notify_fd_, &ke, 1, NULL, 0, NULL) == -1)
+ return false;
+#else
@ -121,7 +128,7 @@
}
virtual MessageLoop* GetNotificationLoop() {
@@ -559,7 +582,7 @@
@@ -559,7 +587,7 @@
// Implement base::MessagePumpLibevent::Delegate.
void OnFileCanReadWithoutBlocking(int fd) {
@ -130,35 +137,44 @@
DCHECK(MessageLoop::current() == file_loop_);
OnChangeNotification();
}
@@ -830,12 +853,24 @@
@@ -830,12 +858,28 @@
// from the inotify file descriptor and starts up a debounce timer if
// an event for kioslaverc is seen.
void OnChangeNotification() {
- DCHECK(inotify_fd_ >= 0);
+ DCHECK(notify_fd_ >= 0);
DCHECK(MessageLoop::current() == file_loop_);
- char event_buf[(sizeof(inotify_event) + NAME_MAX + 1) * 4];
bool kioslaverc_touched = false;
+#if defined(OS_FREEBSD)
+ bool kioslaverc_touched = true;
+ // TODO(gliaskos): We never get here so we don't get events when the
+ // KDE proxy settings change. Find out why :/
+ struct kevent ke;
+ if (kevent(notify_fd_, NULL, 0, &ke, 1, NULL) == -1) {
+ LOG(ERROR) << "kevent() failure: no longer watching kioslaverc";
+ int rv = kevent(notify_fd_, NULL, 0, &ke, 1, NULL);
+
+ if (rv != -1) {
+ kioslaverc_touched = true;
+ } else {
+ LOG(ERROR) << "kevent() failure; no longer watching kioslaverc!";
+ notify_watcher_.StopWatchingFileDescriptor();
+ close(notify_fd_);
+ notify_fd_ = -1;
+ kioslaverc_touched = false;
+ }
+ close(ke.ident);
+#else
char event_buf[(sizeof(inotify_event) + NAME_MAX + 1) * 4];
bool kioslaverc_touched = false;
+ char event_buf[(sizeof(inotify_event) + NAME_MAX + 1) * 4];
ssize_t r;
- while ((r = read(inotify_fd_, event_buf, sizeof(event_buf))) > 0) {
+ while ((r = read(notify_fd_, event_buf, sizeof(event_buf))) > 0) {
// inotify returns variable-length structures, which is why we have
// this strange-looking loop instead of iterating through an array.
char* event_ptr = event_buf;
@@ -865,9 +900,9 @@
// large), but if it does we'd warn continuously since |inotify_fd_|
@@ -862,14 +906,15 @@
if (errno == EINVAL) {
// Our buffer is not large enough to read the next event. This should
// not happen (because its size is calculated to always be sufficiently
// large), but if it does we'd warn continuously since |inotify_fd_|
// would be forever ready to read. Close it and stop watching instead.
LOG(ERROR) << "inotify failure; no longer watching kioslaverc!";
- inotify_watcher_.StopWatchingFileDescriptor();
@ -169,8 +185,11 @@
+ notify_fd_ = -1;
}
}
+#endif
if (kioslaverc_touched) {
@@ -883,8 +918,8 @@
// We don't use Reset() because the timer may not yet be running.
// (In that case Stop() is a no-op.)
@@ -883,8 +928,8 @@
typedef std::map<std::string, std::string> string_map_type;
typedef std::map<std::string, std::vector<std::string> > strings_map_type;

View file

@ -1,5 +1,14 @@
@@ -862,14 +906,15 @@
// Our buffer is not large enough to read the next event. This should
// not happen (because its size is calculated to always be sufficiently
- // large), but if it does we'd warn continuously since |inotify_fd_|
+ // large), but if it does we'd warn continuously since |notify_fd_|
// would be forever ready to read. Close it and stop watching instead.
LOG(ERROR) << "inotify failure; no longer watching kioslaverc!";